@@ -25,17 +25,17 @@
 
 from __future__ import print_function
 
-__revision__ = "src/script/scons.py 27552f9e8d59c13c3567f2bd380b74e34ee25324 2019-01-08 02:59:02 bdbaddog"
+__revision__ = "src/script/scons.py 72ae09dc35ac2626f8ff711d8c4b30b6138e08e3 2019-08-08 14:50:06 bdeegan"
 
-__version__ = "3.0.3"
+__version__ = "3.1.1"
 
-__build__ = "27552f9e8d59c13c3567f2bd380b74e34ee25324"
+__build__ = "72ae09dc35ac2626f8ff711d8c4b30b6138e08e3"
 
-__buildsys__ = "hpmicrodog"
+__buildsys__ = "octodog"
 
-__date__ = "2019-01-08 02:59:02"
+__date__ = "2019-08-08 14:50:06"
 
-__developer__ = "bdbaddog"
+__developer__ = "bdeegan"
 
 # This is the entry point to the SCons program.
 # The only job of this script is to work out where the guts of the program
@@ -68,7 +68,7 @@ Python 2.7 or >= 3.5 is required.\n"
 # Strip the script directory from sys.path so on case-insensitive
 # (WIN32) systems Python doesn't think that the "scons" script is the
 # "SCons" package.
-script_dir = os.path.dirname(__file__)
+script_dir = os.path.dirname(os.path.realpath(__file__))
 script_path = os.path.realpath(os.path.dirname(__file__))
 if script_path in sys.path:
     sys.path.remove(script_path)
