@@ -32,7 +32,7 @@ selection method.
 #
 from __future__ import print_function
 
-__revision__ = "src/engine/SCons/Tool/link.py 3a41ed6b288cee8d085373ad7fa02894e1903864 2019-01-20 22:51:36 bdeegan"
+__revision__ = "src/engine/SCons/Tool/link.py 72ae09dc35ac2626f8ff711d8c4b30b6138e08e3 2019-08-08 14:50:06 bdeegan"
 
 import sys
 import re
@@ -81,6 +81,8 @@ def _lib_emitter(target, source, env, **kw):
     if Verbose:
         print("_lib_emitter: target[0]={!r}".format(target[0].get_path()))
     for tgt in target:
+        if SCons.Util.is_String(tgt):
+            tgt = env.File(tgt)
         tgt.attributes.shared = 1
 
     try:
